################################
## install required packages ###
################################
if(!require("raster")) {
  install.packages("raster")
}

if(!require("rgdal")) {
  install.packages("rgdal")
}

if(!require("sf")) {
  install.packages("sf")
}

if(!require("rgrass7")) {
  install.packages("rgrass7")
}

# TODO: get rid of "dplyr" 

#################
## Basic setup ##
#################
targetdir <- file.path(".","data","derived_data")
base_raster_name <- file.path(targetdir,"dem_agg_utm.tif")
base_fine_raster_name <- file.path(targetdir,"dem_utm.tif")
base_smooth_raster_name <- file.path(targetdir,"dem_smooth.tif")

dem <- raster::raster(base_raster_name)

loc <-  rgrass7::initGRASS("/opt/grass", home=tempdir() ,mapset = "PERMANENT", override = TRUE)

rgrass7::execGRASS("g.proj",
                   flags = c("c"),
                   parameters = list(epsg = 32635))

rgrass7::execGRASS("r.in.gdal",
                   parameters = list(input = base_raster_name,
                                     output = "dem"),
                   flags = c("overwrite","e")
                   )

rgrass7::execGRASS("g.region",
                   parameters = list(raster = "dem"),
                   flags = c("p")
                   )


################
## SMOOTH DEM ##
################
rgrass7::execGRASS("r.param.scale",
                   flags = c("overwrite"),
                   parameters = list(input = "dem",
                                     output = "dem_smooth",
                                     size = 5,
                                     method = "elev"
                                     )
                   )

rgrass7::execGRASS("r.out.gdal",
                   parameters = list(input = "dem_smooth",
                                     output = base_smooth_raster_name,
                                     type = "Float32",
                                     format = "GTiff"),
                   flags = c("overwrite","f"))

###############
## Hillshade ##
###############
rgrass7::execGRASS("r.relief",
                   flags = c("overwrite"),
                   parameters = list(input = "dem_smooth",
                                     output = "hs",
                                     zscale = 2
                                     )
                   )

rgrass7::execGRASS("r.out.gdal",
                   parameters = list(input = "hs",
                                     output = file.path(targetdir,"hs.tif"),
                                     type = "Float32",
                                     format = "GTiff"),
                   flags = c("overwrite","f"))

###########
## Slope ##
###########

rgrass7::execGRASS("r.slope.aspect",
                   parameters = list(elevation = "dem_smooth",
                                     slope = "slope",
                                     format = "degrees"                                     
                                     ),
                   flags = c("overwrite"))

rgrass7::execGRASS("r.out.gdal",
                   parameters = list(input = "slope",
                                     output = file.path(targetdir,"slope.tif"),
                                     type = "Float32",
                                     format = "GTiff"),
                   flags = c("overwrite","f"))

###########
### TWI ###
###########

rgrass7::execGRASS("r.watershed",
                   flags = c("overwrite", "b"),
                   parameters = list(elevation = "dem",
                                     accumulation = "fac",
                                     tci = "twi"
                                     )
                   )

rgrass7::execGRASS("r.out.gdal",
                   parameters = list(input = "twi",
                                     output = file.path(targetdir,"twi.tif"),
                                     type = "Float32",
                                     format = "GTiff"),
                   flags = c("overwrite","f"))


###################
## 10m hillshade ##
###################

rgrass7::execGRASS("g.proj",
                   flags = c("c"),
                   parameters = list(epsg = 32635))

rgrass7::execGRASS("r.in.gdal",
                   parameters = list(input = base_fine_raster_name,
                                     output = "dem"),
                   flags = c("overwrite","e")
                   )

rgrass7::execGRASS("g.region",
                   parameters = list(raster = "dem"),
                   flags = c("p")
                   )
rgrass7::execGRASS("r.relief",
                   flags = c("overwrite"),
                   parameters = list(input = "dem",
                                     output = "hs10",
                                     zscale = 3
                                     )
                   )

rgrass7::execGRASS("r.out.gdal",
                   parameters = list(input = "hs10",
                                     output = file.path(targetdir,"hs10m.tif"),
                                     type = "Float32",
                                     format = "GTiff"),
                   flags = c("overwrite","f"))
