################################
## install required packages ###
################################
if(!require("raster")) {
  install.packages("raster")
}

if(!require("rgdal")) {
  install.packages("rgdal")
}

if(!require("sf")) {
  install.packages("sf")
}

if(!require("rgrass7")) {
  install.packages("rgrass7")
}

# TODO: get rid of "dplyr" 

if(file.exists("./data/derived_data/Micro-Region.gpkg")) {
  file.remove("./data/derived_data/Micro-Region.gpkg")
}

#################
## Basic setup ##
#################
targetdir <- file.path(".","data","derived_data")
base_raster_name <- file.path(targetdir,"dem_utm.tif")

dem <- raster::raster(base_raster_name)

loc <-  rgrass7::initGRASS("/opt/grass", home=tempdir() ,mapset = "PERMANENT", override = TRUE)

rgrass7::execGRASS("g.proj",
                   flags = c("c"),
                   parameters = list(epsg = 32635))

rgrass7::execGRASS("r.in.gdal",
                   parameters = list(input = base_raster_name,
                                     output = "dem"),
                   flags = c("overwrite","e")
                   )

rgrass7::execGRASS("g.region",
                   parameters = list(raster = "dem"),
                   flags = c("p")
                   )

######################
## walking distance ##
######################
pergamon <- read.table("./data/raw_data/Pergamon_site.csv",
                       header = TRUE,
                       sep = ";")
pergamon <- as.numeric(pergamon[pergamon$name=="Pergamon", c("x","y")])

friction <- dem
friction[!is.na(friction[])] <- 1 ## SLOWS DOWN! Assumption: cart/wheeled stuff
raster::writeRaster(friction,
                    file.path(targetdir, "friction.tif"),
                    overwrite = TRUE)

rgrass7::execGRASS("r.in.gdal",
                   parameters = list(input = file.path(targetdir, "friction.tif"),
                                     output = "friction"),
                   flags = c("overwrite")
                   )

rgrass7::execGRASS("r.walk",
                   flags = c("overwrite", "verbose", "k"),
                   parameters = list(elevation = "dem",
                                     friction = "friction",
                                     output = "walking_time",
                                     start_coordinates = pergamon,
                                     memory = 4000
                                     )
                   )

rgrass7::use_sp()
walking_time <- raster::raster(rgrass7::readRAST("walking_time"))
walking_time <- walking_time / 3600
raster::writeRaster(walking_time,
                    file.path(targetdir, "walking_time.tif"),
                    overwrite = TRUE)

one_8hday <- walking_time
one_8hday[one_8hday[] > 8] <- NA
one_8hday[!is.na(one_8hday[])] <- 1
raster::writeRaster(one_8hday,
                    file.path(targetdir, "one_8hday_10m.tif"),
                    overwrite = TRUE)

if(file.exists(file.path(targetdir, "one_8hday.tif"))) {
  file.remove(file.path(targetdir, "one_8hday.tif"))
}
system(paste("gdalwarp",
             "-tr 50 50",
             "-r cubicspline",
             file.path(targetdir, "one_8hday_10m.tif"),
             file.path(targetdir, "one_8hday.tif")))

system(paste("gdal_polygonize.py",             
             file.path(targetdir, "one_8hday.tif"),
             file.path(targetdir, "Micro-Region.gpkg"),
             "one_8hday"
             ))


two_8hday <- walking_time
two_8hday[two_8hday[] > 16] <- NA
two_8hday[!is.na(two_8hday[])] <- 1
raster::writeRaster(two_8hday,
                    file.path(targetdir, "two_8hday_10m.tif"),
                    overwrite = TRUE)

if(file.exists(file.path(targetdir, "two_8hday.tif"))) {
  file.remove(file.path(targetdir, "two_8hday.tif"))
}
system(paste("gdalwarp",
             "-tr 50 50",
             "-r cubicspline",
             file.path(targetdir, "two_8hday_10m.tif"),
             file.path(targetdir, "two_8hday.tif")))

system(paste("gdal_polygonize.py",             
             file.path(targetdir, "two_8hday.tif"),
             file.path(targetdir, "Micro-Region.gpkg"),
             "two_8hday"
             ))

###################
## extract chora ##
###################
chora <- sf::st_read("./data/raw_data/Pergamon_chora_after_Sommerey_2008.gpkg",
                     layer = "Sommerey_Chora")
chora_ras <- dem
chora_ras <- mask(chora_ras, chora)
chora_ras[!is.na(chora_ras[])] <- 1

raster::writeRaster(chora_ras,
                    file.path(targetdir, "chora_ras_10m.tif"),
                    overwrite = TRUE)

if(file.exists(file.path(targetdir, "chora_ras.tif"))) {
  file.remove(file.path(targetdir, "chora_ras.tif"))
}
system(paste("gdalwarp",
             "-tr 50 50",
             "-r cubicspline",
             file.path(targetdir, "chora_ras_10m.tif"),
             file.path(targetdir, "chora_ras.tif")))


########################
## Micro-Region catchment based ##
########################
micro_region_catchment_based <- sf::st_read(
  "./data/raw_data/boundary_valley/Bakircay+Madra.shp")
names(micro_region_catchment_based)[names(micro_region_catchment_based)=="fid"]<-"id"

micro_region_catchment_based_ras <- dem
micro_region_catchment_based_ras <- mask(micro_region_catchment_based_ras, micro_region_catchment_based)
micro_region_catchment_based_ras[!is.na(micro_region_catchment_based_ras[])] <- 1

sf::st_write(micro_region_catchment_based,
             dsn = "./data/derived_data/Micro-Region.gpkg",
             layer = "micro_region_catchment_based",             
             delete_layer = TRUE)

raster::writeRaster(micro_region_catchment_based_ras,
                    file.path(targetdir, "micro_region_catchment_based_ras_10m.tif"),
                    overwrite = TRUE)

if(file.exists(file.path(targetdir, "micro_region_catchment_based_ras.tif"))) {
  file.remove(file.path(targetdir, "micro_region_catchment_based_ras.tif"))
}
system(paste("gdalwarp",
             "-tr 50 50",
             "-r cubicspline",
             file.path(targetdir, "micro_region_catchment_based_ras_10m.tif"),
             file.path(targetdir, "micro_region_catchment_based_ras.tif")))


################################
## cut dem and hs for mapping ##
################################
microregions <- c("micro_region_catchment_based_ras",
                  "chora_ras",
                  "two_8hday",
                  "one_8hday")
                  
cut_microregion <- function(input, microregion, output) {
  input <- raster::raster(file.path(targetdir,input))
  microregion <- raster::raster(file.path(targetdir,paste0(microregion,".tif")))

  raster::writeRaster(x = input * microregion,
                      filename = output,
                      overwrite = TRUE)
}

lapply(X = microregions,
       FUN = function(microregion) {
         cut_microregion(input = "dem_agg_utm.tif",
                         microregion = microregion,
                         output = file.path(targetdir,paste0("dem_",microregion,".tif"))
                         )
       })
                         
                        
       

