## Install packages
if(!require("LandUseQuantifieR")) {
  if(!require('devtools')) install.packages('devtools')
  devtools::install_git('https://gitlab.com/CRC1266-A2/LandUseQuantifieR.git')
}

## Load libraries
library(LandUseQuantifieR)

## Load diet composition file (CSV)
food <- read.csv2("./data/raw_data/food.csv")

## Specify population size
pop <- 200000

## Create dataframe for storing area requirements defined land-use categories 
## and/or plants/animals
df <- data.frame(kcal_req = double(),
                 a_bar = double(),
                 a_whe = double(),
                 a_len = double(),
                 a_pea = double(),
                 a_fav = double(),
                 a_chi = double(),
                 a_fla = double(),
                 a_arb = double(),
                 a_pas = double(),
                 a_woo = double())

## Set range of energy (kcal) needed per day per "average" person
kcal_range = seq(1400,3200, by = 1)

## Iterate over kcal_range and calculate the area requirements per capita for
## each of the defined land-use categories and/or plants/animals
for (i in kcal_range){
  
  # Apply the summarize_areas_kcal function on the set population size and each
  # kcal requirement with the given range
  areas_kcal <- summarize_areas_kcal(
    population = pop,
    kcal_requirement = i,
    household_people = 5,
    food_df = food, 
    aux_animal = "bull",
    forest_type = "oak_mixed_forest", 
    bronze = TRUE, 
    iron = TRUE,
    ceramics = TRUE, 
    olive_oil = TRUE, 
    flax = TRUE)

  # Write the area requirements per capita into the dataframe  
  de <- list(kcal_req = i,
             a_bar = areas_kcal$Crops$area_req_percapita[1],
             a_whe = areas_kcal$Crops$area_req_percapita[2],
             a_len = areas_kcal$Crops$area_req_percapita[3],
             a_pea = areas_kcal$Crops$area_req_percapita[4],
             a_fav = areas_kcal$Crops$area_req_percapita[5],
             a_chi = areas_kcal$Crops$area_req_percapita[6],
             a_fla = areas_kcal$Flax$area_req / pop,
             a_arb = areas_kcal$"Area Requirements"$Area_ha[3] / pop,
             a_pas = areas_kcal$"Area Requirements"$Area_ha[4] / pop,
             a_woo = areas_kcal$"Area Requirements"$Area_ha[5] / pop)
  
  # Append the new row to the dataframe 
  df <- rbind(df, de)
}

## Export the dataframe as CSV for further use
write.csv2(df,"./data/derived_data/kcal_change.csv")
